pub(crate) struct BootloaderEntry {
pub(crate) fsverity: String,
pub(crate) boot_artifact_name: String,
}Fields
fsverity: StringThe fsverity digest associated with the bootloader entry This is the value of composefs= param
boot_artifact_name: StringThe name of the (UKI/Kernel+Initrd directory) related to the entry
For UKI, this is the name of the UKI stripped of our custom prefix and .efi suffix
For Type1 entries, this is the name to the directory containing Kernel+Initrd, stripped of our custom prefix
Since this is stripped of all our custom prefixes + file extensions this is basically the verity digest part of the name
We mainly need this in order to GC shared Type1 entries